@@ -24,44 +24,6 @@ def getattr_value(arr, key):
     return getattr(arr, key) if key in arr else ''
 
 
-def where_is(program):
-    """
-    Protected method enabling the object to find the full path of a binary
-    from its PATH environment variable.
-    :param program: name of a binary for which the full path needs to
-    be discovered.
-    :return: the full path to the binary.
-    :todo: add a default path list in case PATH is empty.
-    """
-    __is_windows = (platform.system() == 'Windows')
-    split_char = ';' if __is_windows else ':'
-    program = program + '.exe' if __is_windows else program
-    paths = os.environ.get('PATH', '').split(split_char)
-    for path in paths:
-        if (os.path.exists(os.path.join(path, program)) and not
-        os.path.isdir(os.path.join(path, program))):
-            if not platform.system() == 'Windows':
-                return os.path.join(path, program)
-            else:
-                return '\"' + os.path.join(path, program) + '\"'
-    return None
-
-
-def get_real_link(bath_path: str):
-    """
-    传入文件的绝对路径，返回文件的源文件的绝对路径
-    :param bath_path:
-    :return:
-    """
-    if os.path.islink(bath_path):
-        real_link = os.readlink(bath_path)
-        bath_path = os.path.abspath(os.path.dirname(bath_path))
-        path = os.path.join(bath_path, real_link)
-        return get_real_link(path)
-    else:
-        return bath_path
-
-
 def get_valid_filename(s):
     """
     Return the given string converted to a string that can be used for a clean filename.
@@ -319,27 +281,6 @@ def random_colorama(text: str, length=4):
     return new_text
 
 
-def mongodb_point_convert_tom(d: dict):
-    if 'targets' in d and d['targets']:
-        t = d['targets']
-        if isinstance(t, dict):
-            convert_ip(t)
-    if 'exist_targets' in d and d['exist_targets']:
-        t = d['exist_targets']
-        if isinstance(t, dict):
-            convert_ip(t)
-    return d
-
-
-def convert_ip(t: dict):
-    for key in list(t):
-        if '.' in key:
-            nk = str(key).replace('.', '|')
-            t[nk] = t.pop(key)
-
-    return t
-
-
 def updateJsonObjectFromStr(base_obj, update_str: str):
     assert (type(base_obj) in (list, dict))
     base_obj = copy.deepcopy(base_obj)
