@@ -64,18 +64,31 @@ def abs_find_program(program):
     for path in paths:
         if (os.path.exists(os.path.join(path, program)) and not
         os.path.isdir(os.path.join(path, program))):
-            if not __is_windows == 'Windows':
+            if not __is_windows:
                 return os.path.join(path, program)
             else:
                 return '\"' + os.path.join(path, program) + '\"'
     return None
 
 
+def abs_find_real_link(bath_path: str):
+    """
+    传入文件的绝对路径，返回文件的源文件的绝对路径
+    :param bath_path:
+    :return:
+    """
+    if os.path.islink(bath_path):
+        real_link = os.readlink(bath_path)
+        bath_path = os.path.abspath(os.path.dirname(bath_path))
+        path = os.path.join(bath_path, real_link)
+        return abs_find_real_link(path)
+    else:
+        return bath_path
+
+
 def safe_path(path):
     return path.replace('/', '\\') if SYS == 'Windows' else path.replace('\\', '/')
 
 
 def _combine_path(path_a, path_b):
     pass
-
-
